ApiClient class

Constructors

ApiClient()
factory

Properties

apiKey String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguage String?
getter/setter pair
targetLanguage String?
getter/setter pair

Methods

getTranslationForKey(String key, {String? sourceLanguageCode, String? targetLanguageCode}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
translateData(Map<String, String> data, {String? sourceLanguageCode, String? targetLanguageCode, List<String>? ignoreWords}) Future<Map<String, String>>
translateText(String text, {String? sourceLanguageCode, String? targetLanguageCode, List<String>? ignoreWords}) Future<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize({required String apiKey, String? sourceLanguage, String? targetLanguage}) ApiClient