HttpApiClient class

Constructors

HttpApiClient(String apiKey)

Properties

apiKey String
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performDataTranslationRequest(Map<String, String> data, String sourceLang, String targetLang, List<String> ignoreWords) Future<Map<String, String>>
performTextTranslationRequest(String text, String sourceLang, String targetLang, List<String> ignoreWords) Future<String?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited